#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_INTERLEAVE_FIRST_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_INTERLEAVE_FIRST_HPP_INCLUDED

#include <boost/simd/swar/include/functions/simd/interleave_first.hpp>

#endif
